https://github.com/OpenStuder/openstuder-client-python 

![GitHub](https://img.shields.io/pypi/v/openstuder-client.svg)
![GitHub](https://img.shields.io/github/license/openstuder/openstuder-client-python)
![GitHub](https://img.shields.io/github/issues-raw/openstuder/openstuder-client-python)

See the [documentation](http://openstuder.github.io/#/clientlibs) on how to install and use the python client library. 
